@@ -51,7 +51,7 @@ const FileAnnotation* Annotate::lookupAnnotation(SCRef sha, SCRef fn) {
 
 bool Annotate::startPatchProc(SCRef buf, SCRef fileName) {
 
-	QString cmd("git diff-tree -r -m --patch-with-raw --no-commit-id --stdin --");
+	QString cmd("git diff-tree --no-color -r -m --patch-with-raw --no-commit-id --stdin --");
 	QStringList args(QStringList::split(' ', cmd));
 	args.append(fileName); // handle file name with spaces case
 	patchProc.setArguments(args);
@@ -385,8 +385,8 @@ void Annotate::setAnnotation(SCRef diff, SCRef author, SCList prevAnn,
 			// message is locale dependent, so just test the space after '\'
 			if (line[1] == ' ')
 				break;
-			else
-				; // fall through
+
+			// fall through
 		default:
 			++cur;
 			break;
@@ -409,7 +409,7 @@ const QString Annotate::getNextPatch(QString& patchFile, SCRef fileName, SCRef s
 		// diff-tree --stdin doesn't work with working dir so get it
 		// directly. We don't need file sha info because is ZERO_SHA
 		QString runOutput;
-		QString runCmd("git diff-index -r -m -p HEAD -- " + QGit::QUOTE_CHAR +
+		QString runCmd("git diff-index --no-color -r -m -p HEAD -- " + QGit::QUOTE_CHAR +
 				fileName + QGit::QUOTE_CHAR);
 
 		git->run(runCmd, &runOutput);
@@ -737,6 +737,12 @@ const QString Annotate::getAncestor(SCRef sha, SCRef fileName, int* shaIdx) {
 		if (fa.fileSha == fileSha)
 			return histRevOrder[*shaIdx];
 	}
+	// ok still not found, this could happen if sha is an unapplied
+	// stgit patch. In this case fall back on the first in the list
+	// that is the newest.
+	if (git->getAllRefSha(Git::UN_APPLIED).contains(sha))
+		return histRevOrder.first();
+
 	dbp("ASSERT in getAncestor: ancestor of %1 not found", sha);
 	return "";
 }
